#
# Do not edit this file (it is autogenerated)!
#

###################################
package PDF::PDFUnit::StudyClasses;
###################################
use strict;
use warnings;

our $java_classes = [
    'com.pdfunit.AssertThat',
    'com.pdfunit.Constants',
    'com.pdfunit.PDFVersion',
    'com.pdfunit.Standard',
    'com.pdfunit.VersionInfo',
    'com.pdfunit.WhitespaceProcessing',
    'com.pdfunit.ZugferdVersion',
    'com.pdfunit.filter.file.FilenameContainingFilter',
    'com.pdfunit.filter.file.FilenameMatchingFilter',
    'com.pdfunit.filter.page.PagesFromTo',
    'com.pdfunit.filter.page.PagesToUse',
    'com.pdfunit.filter.region.PageRegion',
    'com.pdfunit.util.ConfigHelper',
    'com.pdfunit.util.DateHelper',
    'com.pdfunit.util.IOHelper',
    'com.pdfunit.util.ImageHelper',
    'com.pdfunit.xml.DefaultNamespace',
    'com.pdfunit.xml.XMLNode',
    'java.io.File',
    'java.io.FileInputStream',
    'java.net.URL',
];


1;

__END__

=head1 NAME

PDF::PDFUnit::StudyClasses - Helper module


=head1 DESCRIPTION

Nothing in here is meant for public consumption.
