#
# Do not edit this file (it is autogenerated)!
#

#####################
package PDF::PDFUnit;
#####################

# We want to make this stuff usable by just doing "use PDF::PDFUnit".
# Therefore no different namespace here!

use strict;
use warnings;

require Exporter;
our @ISA = qw(Exporter);
push @PDF::PDFUnit::EXPORT, qw(
    AssertThat
    ConfigHelper
    DateHelper
    DefaultNamespace
    File
    FileInputStream
    FilenameContainingFilter
    FilenameMatchingFilter
    ImageHelper
    IOHelper
    PageRegion
    PagesFromTo
    PagesToUse
    PDFVersion
    URL
    VersionInfo
    XMLNode
);


use constant {
    AssertThat => 'com::pdfunit::AssertThat',
    ConfigHelper => 'com::pdfunit::util::ConfigHelper',
    DateHelper => 'com::pdfunit::util::DateHelper',
    DefaultNamespace => 'com::pdfunit::xml::DefaultNamespace',
    File => 'java::io::File',
    FileInputStream => 'java::io::FileInputStream',
    FilenameContainingFilter => 'com::pdfunit::filter::file::FilenameContainingFilter',
    FilenameMatchingFilter => 'com::pdfunit::filter::file::FilenameMatchingFilter',
    ImageHelper => 'com::pdfunit::util::ImageHelper',
    IOHelper => 'com::pdfunit::util::IOHelper',
    PageRegion => 'com::pdfunit::filter::region::PageRegion',
    PagesFromTo => 'com::pdfunit::filter::page::PagesFromTo',
    PagesToUse => 'com::pdfunit::filter::page::PagesToUse',
    PDFVersion => 'com::pdfunit::PDFVersion',
    URL => 'java::net::URL',
    VersionInfo => 'com::pdfunit::VersionInfo',
    XMLNode => 'com::pdfunit::xml::XMLNode',
};




package Standard;
sub PDFA_1A { $com::pdfunit::Standard::PDFA_1A }
sub PDFA_1B { $com::pdfunit::Standard::PDFA_1B }

package WhitespaceProcessing;
sub IGNORE { $com::pdfunit::WhitespaceProcessing::IGNORE }
sub NORMALIZE { $com::pdfunit::WhitespaceProcessing::NORMALIZE }
sub KEEP { $com::pdfunit::WhitespaceProcessing::KEEP }

package ZugferdVersion;
sub VERSION10 { $com::pdfunit::ZugferdVersion::VERSION10 }



1;

__END__

=head1 NAME

PDF::PDFUnit::Shortcuts - Shortcuts exported by PDF::PDFUnit

=head1 DESCRIPTION

I<PDF::PDFUnit> exports the following shortcuts (i.e. constants)
into your namespace (in alphabetical order):

=over


=item B<AssertThat>


=item B<ConfigHelper>


=item B<DateHelper>


=item B<DefaultNamespace>


=item B<File>


=item B<FileInputStream>


=item B<FilenameContainingFilter>


=item B<FilenameMatchingFilter>


=item B<ImageHelper>


=item B<IOHelper>


=item B<PageRegion>


=item B<PagesFromTo>


=item B<PagesToUse>


=item B<PDFVersion>


=item B<URL>


=item B<VersionInfo>


=item B<XMLNode>


=back

And also these, included in packages:

=over


=item B<Standard::PDFA_1A>


=item B<Standard::PDFA_1B>


=item B<WhitespaceProcessing::IGNORE>


=item B<WhitespaceProcessing::NORMALIZE>


=item B<WhitespaceProcessing::KEEP>


=item B<ZugferdVersion::VERSION10>


=back
